@@ -149,21 +149,41 @@ makeProblem <- function(data, dimList, dimVarInd, freqVarInd=NULL, numVarInd=NUL
       }
     }
 
-    # remove duplicates, standardize and calculate strID
-    dt <- rawData[,dimVarInd, with=F]
-    for ( i in seq_along(dimVarInd) ) {
-      dups <- g_dups(inputDims[[i]])
-      if ( length(dups) > 0 ) {
-        cmd <- paste0("dt <- dt[!",names(dt)[i],"%in% c('",paste(dups, collapse="','"),"')]")
-        eval(parse(text=cmd))
-      }
-    }
     ss <- list()
-    for ( i in 1:ncol(dt) ) {
-      if ( !c_has_default_codes(inputDims[[i]], input=dt[[i]]) ) {
-        ss[[i]] <- c_standardize(inputDims[[i]], input=dt[[dimVarInd[i]]])
+    for ( i in seq_along(dimVarInd) ) {
+      remove.vals <- FALSE
+      remove_ind <- NULL
+      if ( !c_has_default_codes(inputDims[[i]], input=rawData[[dimVarInd[i]]]) ) {
+        dups <- g_dups(inputDims[[i]])
+        if ( length(dups) > 0 ) {
+          dupsUp <- g_dups_up(inputDims[[i]])
+          for ( k in length(dups):1 ) {
+            ind <- which(rawData[[dimVarInd[i]]]==dups[k])
+            if ( length(ind) > 0 ) {
+              if ( length(which(rawData[[dimVarInd[i]]]==dupsUp[k])) > 0 ) {
+                remove.vals <- TRUE
+                remove_ind <- c(remove_ind, ind)
+              } else {
+                rawData[[dimVarInd[i]]][ind] <- dupsUp[k]
+              }
+            }
+          }
+          if ( remove.vals ) {
+            rawData <- rawData[-remove_ind]
+          }
+          s_raw_data(inputData) <- list(rawData)
+        }
+        ss[[i]] <- c_standardize(inputDims[[i]], input=rawData[[dimVarInd[i]]])
       } else {
-        ss[[i]] <- dt[[i]]
+        ss[[i]] <- rawData[[dimVarInd[i]]]
+      }
+      # remove entries in ss[[1]...ss[[i-1]]
+      if ( remove.vals ) {
+        if ( i > 1 ) {
+          for ( z in 1:(i-1)) {
+            ss[[z]] <- ss[[z]][-remove_ind]
+          }
+        }
       }
     }
     strID <- pasteStrVec(as.vector(unlist(ss)), length(posIndex))
@@ -395,6 +415,7 @@ protectTable <- function(object, method, ...) {
 
   if ( method == 'SIMPLEHEURISTIC' ) {
     out <- c_quick_suppression(object, input=paraList)
+    out <- out$object
   } else {
     if ( paraList$useC ) {
       if ( method == "OPT" ) {
